@@ -582,28 +582,28 @@ int connect_to_fcgi_server(t_connect_to *connect_to) {
 				sock = -1;
 			}
 		}
-	} else if (connect_to->host.family == AF_INET) {
+	} else if (connect_to->ip_addr.family == AF_INET) {
 		/* IPv4
 		 */
 		if ((sock = socket(AF_INET, SOCK_STREAM, 0)) > 0) {
 			memset(&saddr4, 0, sizeof(struct sockaddr_in));
 			saddr4.sin_family = AF_INET;
 			saddr4.sin_port = htons(connect_to->port);
-			memcpy(&saddr4.sin_addr.s_addr, &(connect_to->host.value), connect_to->host.size);
+			memcpy(&saddr4.sin_addr.s_addr, &(connect_to->ip_addr.value), connect_to->ip_addr.size);
 			if (connect(sock, (struct sockaddr*)&saddr4, sizeof(struct sockaddr_in)) != 0) {
 				close(sock);
 				sock = -1;
 			}
 		}
 #ifdef ENABLE_IPV6
-	} else if (connect_to->host.family == AF_INET6) {
+	} else if (connect_to->ip_addr.family == AF_INET6) {
 		/* IPv6
 		 */
 		if ((sock = socket(AF_INET6, SOCK_STREAM, 0)) > 0) {
 			memset(&saddr6, 0, sizeof(struct sockaddr_in6));
 			saddr6.sin6_family = AF_INET6;
 			saddr6.sin6_port = htons(connect_to->port);
-			memcpy(&saddr6.sin6_addr.s6_addr, &(connect_to->host.value), connect_to->host.size);
+			memcpy(&saddr6.sin6_addr.s6_addr, &(connect_to->ip_addr.value), connect_to->ip_addr.size);
 			if (connect(sock, (struct sockaddr*)&saddr6, sizeof(struct sockaddr_in6)) != 0) {
 				close(sock);
 				sock = -1;
@@ -624,7 +624,7 @@ int send_fcgi_request(t_session *session, int sock) {
 	fcgi_buffer.size = 0;
 
 	fcgi_buffer.mode = 4;
-	if (send_directly(sock, "\x01\x01\x00\x01" "\x00\x08\x00\x00" "\x00\x01\x00\x00" "\x00\x00\x00\x00", 16) == -1) {
+	if (write_buffer(sock, "\x01\x01\x00\x01" "\x00\x08\x00\x00" "\x00\x01\x00\x00" "\x00\x00\x00\x00", 16) == -1) {
 		return -1;
 	}
 	set_environment(session, &fcgi_buffer);
