@@ -111,7 +111,7 @@ void set_environment(t_session *session, t_fcgi_buffer *fcgi_buffer) {
 	size_t len1, len2, path_info_len;
 	bool has_path_info = false;
 	t_headerfield *headerfields;
-	t_keyvalue *envir, *header;
+	t_keyvalue *envir;
 #ifdef ENABLE_SSL
 	char subject[SSL_VAR_SIZE], issuer[SSL_VAR_SIZE];
 #endif
