@@ -395,11 +395,11 @@ bool in_iplist(t_iplist *list, t_ip_addr *ip) {
 	return false;
 }
 
-/*---< key/valuelist >-------------------------------------------------------*/
+/*---< key/value >-----------------------------------------------------------*/
 
-/* Parse a list of key/value combinations.
+/* Parse a key/value combination.
  */
-int parse_keyvaluelist(char *line, t_keyvalue **kvlist, char *delimiter) {
+int parse_keyvalue(char *line, t_keyvalue **kvlist, char *delimiter) {
 	char *value;
 	t_keyvalue *prev;
 
