@@ -225,11 +225,15 @@ int ssl_accept(t_ssl_accept_data *sad, int timeout) {
 	result = 0;
 	while ((handshake = ssl_handshake(sad->ssl)) != 0) {
 		if ((handshake != POLARSSL_ERR_NET_WANT_READ) && (handshake != POLARSSL_ERR_NET_WANT_WRITE)) {
+			ssl_free(sad->ssl);
+			sad->ssl = NULL;
 			result = -1;
 			break;
 		}
 		if (time(NULL) - start_time >= timeout) {
-			result = -1;
+			ssl_free(sad->ssl);
+			sad->ssl = NULL;
+			result = -2;
 			break;
 		}
 	}
