@@ -178,7 +178,7 @@ void log_request(t_session *session) {
 	char str[BUFFER_SIZE + 1], timestamp[TIMESTAMP_SIZE], ip_address[IP_ADDRESS_SIZE];
 	char *user, *field, *uri, *vars, *path_info;
 	t_headerfield *headerfield;
-	int offset, len;
+	int offset;
 	time_t t;
 	struct tm *s;
 
