@@ -16,11 +16,13 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <stdlib.h>
+#include <unistd.h>
 #include <sys/un.h>
 #include <errno.h>
 #include <string.h>
 #include <time.h>
 #include "global.h"
+#include "libstr.h"
 #include "rproxy.h"
 #ifdef ENABLE_SSL
 #include "libssl.h"
@@ -172,11 +174,12 @@ bool rproxy_loop_detected(t_headerfield *headerfields) {
 /* Init reverse proxy options record
  */
 void init_rproxy_options(t_rproxy_options *options, int socket, t_ip_addr *client_ip, char *method,
-                         char *uri, t_headerfield *headerfields, char *body, int body_length) {
+                         char *uri, char *vars, t_headerfield *headerfields, char *body, int body_length) {
 	options->client_socket = socket;
 	options->client_ip = client_ip;
 	options->method = method;
 	options->uri = uri;
+	options->vars = vars;
 	options->headerfields = headerfields;
 	options->body = body;
 	options->body_length = body_length;
@@ -185,7 +188,7 @@ void init_rproxy_options(t_rproxy_options *options, int socket, t_ip_addr *clien
 /* Connect to the webserver
  */
 int connect_to_webserver(t_rproxy *rproxy) {
-	int sock = -1, max_len;
+	int sock = -1;
 	struct sockaddr_in saddr4;
 #ifdef ENABLE_IPV6
 	struct sockaddr_in6 saddr6;
@@ -274,6 +277,16 @@ int send_request_to_webserver(t_rproxy_webserver *webserver, t_rproxy_options *o
 		return -1;
 	}
 
+	/* URL parameters
+	 */
+	if (options->vars != NULL) {
+		if (send_to_webserver(webserver, "?", 1) == -1) {
+			return -1;
+		} else if (send_to_webserver(webserver, options->vars, strlen(options->vars)) == -1) {
+			return -1;
+		}
+	}
+
 	/* Send HTTP headers
 	 */
 	if (send_to_webserver(webserver, "Host: ", 6) == -1) {
