@@ -544,66 +544,23 @@ int execute_cgi(t_session *session) {
 		}
 	}
 
+	/* Prevent Cross-site Scripting
+	 */
 	if (session->host->prevent_xss) {
-		/* Prevent Cross-site Scripting
-		 */
 		prevent_xss(session);
 	}
 
+	/* Prevent Cross-site Request Forgery
+	 */
 	if (session->host->prevent_csrf) {
-		/* Prevent Cross-site Request Forgery
-		 */
 		prevent_csrf(session);
 	}
 
+	/* Prevent SQL injection
+	 */
 	if (session->host->prevent_sqli) {
-		/* Prevent SQL injection
-		 */
-		if (session->request_uri != NULL) {
-			switch (prevent_sqli(session, session->request_uri, strlen(session->request_uri))) {
-				case -1:
-					return 500;
-				case 0:
-					break;
-				default:
-					session->error_cause = ec_SQL_INJECTION;
-					return -1;
-			}
-		}
-		if (session->vars != NULL) {
-			switch (prevent_sqli(session, session->vars, strlen(session->vars))) {
-				case -1:
-					return 500;
-				case 0:
-					break;
-				default:
-					session->error_cause = ec_SQL_INJECTION;
-					return -1;
-			}
-		}
-
-		if (session->body != NULL) {
-			switch (prevent_sqli(session, session->body, session->content_length)) {
-				case -1:
-					return 500;
-				case 0:
-					break;
-				default:
-					session->error_cause = ec_SQL_INJECTION;
-					return -1;
-			}
-		}
-
-		if (session->cookie != NULL) {
-			switch (prevent_sqli(session, session->cookie, strlen(session->cookie))) {
-				case -1:
-					return 500;
-				case 0:
-					break;
-				default:
-					session->error_cause = ec_SQL_INJECTION;
-					return -1;
-			}
+		if ((result = prevent_sqli(session)) != 0) {
+			return result;
 		}
 	}
 
@@ -1411,8 +1368,8 @@ int proxy_request(t_session *session, t_rproxy *rproxy) {
 	/* Intialize data structure
 	 */
 	init_rproxy_options(&options, session->client_socket, &(session->ip_address),
-	                    session->method, session->request_uri, session->headerfields,
-	                    session->body, session->content_length);
+	                    session->method, session->request_uri, session->vars,
+	                    session->headerfields, session->body, session->content_length);
 
 	session->keep_alive = false;
 
