@@ -475,7 +475,7 @@ int add_tag(char **buffer, int *size, int extra_size, int *len, char *tag, char
 int show_index(t_session *session) {
 	xmlDocPtr data_xml;
 	char *text_xml, fsize_str[30], timestr[33], value[VALUE_SIZE + 1], *extension, *link, *slash, *ruri;
-	int text_size, text_max, fsize_len, result, handle;
+	int text_size, text_max, result, handle;
 	off_t total_fsize = 0;
 	bool root_dir, show_xml;
 	struct tm s;
@@ -656,7 +656,7 @@ int show_index(t_session *session) {
 		if (file->is_dir == false) {
 			/* File size
 		 	 */
-			fsize_len = filesize2str(fsize_str, 30, file->size);
+			filesize2str(fsize_str, 30, file->size);
 			if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "\" size=\"") == -1) {
 				free(text_xml);
 				remove_filelist(filelist);
@@ -789,7 +789,7 @@ int show_index(t_session *session) {
 
 	/* Total size
 	 */
-	fsize_len = filesize2str(fsize_str, 30, total_fsize);
+	filesize2str(fsize_str, 30, total_fsize);
 	if (add_tag(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "total_size", fsize_str) == -1) {
 		free(text_xml);
 		return -1;
